@@ -1,35 +1,17 @@
 /*
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Kevin Krammer, krake@kdab.com
-  Author: Sergio Martins, sergio@kdab.com
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
+  SPDX-FileContributor: Sergio Martins <sergio@kdab.com>
 
   Marcus Bains line.
-  Copyright (c) 2001 Ali Rahimi <ali@mit.edu>
+  SPDX-FileCopyrightText: 2001 Ali Rahimi <ali@mit.edu>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #include "agenda.h"
-#include "agendaitem.h"
 #include "agendaview.h"
-#include "viewcalendar.h"
 #include "prefs.h"
 
 #include <Akonadi/Calendar/ETMCalendar>
@@ -37,7 +19,6 @@
 #include <CalendarSupport/Utils>
 
 #include <KCalendarCore/Incidence>
-#include <KCalendarCore/Todo>
 
 #include <KCalUtils/RecurrenceActions>
 
@@ -68,21 +49,18 @@ public:
     Private(EventView *eventView, Agenda *agenda)
         : mEventView(eventView)
         , mAgenda(agenda)
-        , mTimer(nullptr)
-        , mTimeBox(nullptr)
-        , mOldTodayCol(-1)
     {
     }
 
     int todayColumn() const;
 
 public:
-    EventView *mEventView = nullptr;
-    Agenda *mAgenda = nullptr;
+    EventView *const mEventView;
+    Agenda *const mAgenda;
     QTimer *mTimer = nullptr;
     QLabel *mTimeBox = nullptr;  // Label showing the current time
     QDateTime mOldDateTime;
-    int mOldTodayCol;
+    int mOldTodayCol = -1;
 };
 
 int MarcusBains::Private::todayColumn() const
@@ -226,7 +204,7 @@ public:
         , mHolidayMask(nullptr)
         , mWorkingHoursYTop(0)
         , mWorkingHoursYBottom(0)
-        , mHasSelection(0)
+        , mHasSelection(false)
         , mSelectedId(-1)
         , mMarcusBains(nullptr)
         , mActionType(Agenda::NOP)
@@ -1794,7 +1772,7 @@ QVector<int> Agenda::maxContentsY() const
     return maxArray;
 }
 
-void Agenda::setStartTime(const QTime &startHour)
+void Agenda::setStartTime(QTime startHour)
 {
     const double startPos
         = (startHour.hour() / 24. + startHour.minute() / 1440. + startHour.second() / 86400.)
